@@ -235,16 +235,16 @@ CREATE TABLE "cd" (
   "genreid" integer,
   "single_track" integer,
   FOREIGN KEY ("artist") REFERENCES "artist"("artistid") ON DELETE CASCADE ON UPDATE CASCADE,
-  FOREIGN KEY ("genreid") REFERENCES "genre"("genreid") ON DELETE SET NULL ON UPDATE CASCADE,
-  FOREIGN KEY ("single_track") REFERENCES "track"("trackid") ON DELETE CASCADE
+  FOREIGN KEY ("single_track") REFERENCES "track"("trackid") ON DELETE CASCADE,
+  FOREIGN KEY ("genreid") REFERENCES "genre"("genreid") ON DELETE SET NULL ON UPDATE CASCADE
 );
 
 CREATE INDEX "cd_idx_artist" ON "cd" ("artist");
 
-CREATE INDEX "cd_idx_genreid" ON "cd" ("genreid");
-
 CREATE INDEX "cd_idx_single_track" ON "cd" ("single_track");
 
+CREATE INDEX "cd_idx_genreid" ON "cd" ("genreid");
+
 CREATE UNIQUE INDEX "cd_artist_title" ON "cd" ("artist", "title");
 
 CREATE TABLE "collection_object" (
@@ -287,6 +287,8 @@ CREATE TABLE "lyric_versions" (
 
 CREATE INDEX "lyric_versions_idx_lyric_id" ON "lyric_versions" ("lyric_id");
 
+CREATE UNIQUE INDEX "lyric_versions_lyric_id_text" ON "lyric_versions" ("lyric_id", "text");
+
 CREATE TABLE "tags" (
   "tagid" INTEGER PRIMARY KEY NOT NULL,
   "cd" integer NOT NULL,
@@ -368,4 +370,4 @@ CREATE INDEX "fourkeys_to_twokeys_idx_f_foo_f_bar_f_hello_f_goodbye" ON "fourkey
 CREATE INDEX "fourkeys_to_twokeys_idx_t_artist_t_cd" ON "fourkeys_to_twokeys" ("t_artist", "t_cd");
 
 CREATE VIEW "year2000cds" AS
-    SELECT cdid, artist, title, year, genreid, single_track FROM cd WHERE year = "2000";
+    SELECT cdid, artist, title, year, genreid, single_track FROM cd WHERE year = '2000';
